@@ -53,7 +53,8 @@
 #' @param alpha The significance level to calculate confidence intervals.
 #' @param ties The method for handling ties in the Cox model, either
 #'   "breslow" or "efron" (default).
-#' @param tol The desired accuracy (convergence tolerance) for \code{psi}.
+#' @param tol The desired accuracy (convergence tolerance) for \code{psi} 
+#'   for the root finding algorithm.
 #' @param boot Whether to use bootstrap to obtain the confidence
 #'   interval for hazard ratio. Defaults to \code{FALSE}, in which case,
 #'   the confidence interval will be constructed to match the log-rank
@@ -92,7 +93,9 @@
 #'   for the ITT analysis.
 #'
 #' * \code{cox_pvalue}: The two-sided p-value for treatment effect based on
-#'   the Cox model.
+#'   the Cox model applied to counterfactual unswitched survival times. 
+#'   If \code{boot} is \code{TRUE}, this value represents the 
+#'   bootstrap p-value.
 #'
 #' * \code{hr}: The estimated hazard ratio from the Cox model.
 #'
@@ -107,12 +110,18 @@
 #'   limits of confidence interval of \code{psi} need be modified.
 #'
 #' * \code{Sstar}: A data frame containing the counterfactual untreated
-#'   survival times and event indicators for each treatment group.
+#'   survival times and event indicators for each treatment group. 
+#'   The variables include \code{id}, \code{stratum}, 
+#'   \code{"t_star"}, \code{"d_star"}, \code{"treated"}, and \code{treat}.
 #'
 #' * \code{kmstar}: A data frame containing the Kaplan-Meier estimates
 #'   based on the counterfactual untreated survival times by treatment arm.
 #'
-#' * \code{data_outcome}: The input data for the outcome Cox model.
+#' * \code{data_outcome}: The input data for the outcome Cox model of 
+#'   counterfactual unswitched survival times. 
+#'   The variables include \code{id}, \code{stratum}, 
+#'   \code{"t_star"}, \code{"d_star"}, \code{"treated"}, \code{base_cov},
+#'   and \code{treat}.
 #'
 #' * \code{fit_outcome}: The fitted outcome Cox model.
 #'
@@ -173,7 +182,7 @@
 #' Ian R. White, Adbel G. Babiker, Sarah Walker, and Janet H. Darbyshire.
 #' Randomization-based methods for correcting for treatment changes:
 #' Examples from the CONCORDE trial.
-#' Statistics in Medicine. 1999;18:2617-2634.
+#' Statistics in Medicine. 1999;18(19):2617-2634.
 #'
 #' @examples
 #'
@@ -217,7 +226,7 @@ rpsftm <- function(data, id = "id", stratum = "",
                    time = "time", event = "event",
                    treat = "treat", rx = "rx", censor_time = "censor_time",
                    base_cov = "", low_psi = -1, hi_psi = 1,
-                   n_eval_z = 100, treat_modifier = 1,
+                   n_eval_z = 101, treat_modifier = 1,
                    recensor = TRUE, admin_recensor_only = TRUE,
                    autoswitch = TRUE, gridsearch = FALSE,
                    alpha = 0.05, ties = "efron", tol = 1.0e-6,
@@ -236,15 +245,15 @@ rpsftm <- function(data, id = "id", stratum = "",
   nvar = length(base_cov)
   if (missing(base_cov) || is.null(base_cov) || (nvar == 1 && (
     base_cov[1] == "" || tolower(base_cov[1]) == "none"))) {
-    p3 = 0
+    p = 0
   } else {
     t1 = terms(formula(paste("~", paste(base_cov, collapse = "+"))))
     t2 = attr(t1, "factors")
     t3 = rownames(t2)
-    p3 = length(t3)
+    p = length(t3)
   }
 
-  if (p3 >= 1) {
+  if (p >= 1) {
     mm = model.matrix(t1, df)
     colnames(mm) = make.names(colnames(mm))
     varnames = colnames(mm)[-1]
@@ -272,5 +281,22 @@ rpsftm <- function(data, id = "id", stratum = "",
   out$data_outcome$uid <- NULL
   out$data_outcome$ustratum <- NULL
   
+  if (p >= 1) {
+    t1 = terms(formula(paste("~", paste(base_cov, collapse = "+"))))
+    t2 = attr(t1, "factors")
+    t3 = rownames(t2)
+    
+    add_vars <- setdiff(t3, varnames)
+    if (length(add_vars) > 0) {
+      out$data_outcome <- merge(out$data_outcome, df[, c(id, add_vars)], 
+                                by = id, all.x = TRUE, sort = FALSE)
+    }
+    
+    del_vars <- setdiff(varnames, t3)
+    if (length(del_vars) > 0) {
+      out$data_outcome[, del_vars] <- NULL
+    }
+  }
+  
   out
 }
